gs_quant.timeseries.algebra.sqrt — gs_quant 0.1 documentation

# gs_quant.timeseries.algebra.sqrt

`sqrt`(x)

  Square root of (a) each element in a series or (b) a real number

  Parameters

    x (`Union`[`Real`, `Series`]) – date-based time series of prices or real number

  Return type

    `Union`[`Real`, `Series`]

  Returns

    date-based time series of square roots or square root of given number

  Usage

  Return the square root of each value in time series \(X_t\):

  \(R_t = \sqrt{X_t}\)

  Examples

  Generate price series and take square root of each value:

      >>> prices = generate_series(100)
      >>> sqrt(prices)

  See also

  `pow()`